import type { ComputedRef } from 'vue';
export declare const LIGHT_SCHEME = "light";
export declare const DARK_SCHEME = "dark";
export declare const SYSTEM_SCHEME = "system";
export type Preferences = {
    theme: 'light' | 'dark';
    scheme: 'light' | 'dark' | 'system';
};
/**
 * @property {(scheme: string) => void} setScheme - Fonction pour mettre à jour le scheme
 * @property {string} scheme - Scheme courant
 * @property {string} theme - Thème courant en fonction du scheme
 */
export declare type UseSchemeResult = {
    setScheme: (scheme: string) => void;
    scheme: ComputedRef<string>;
    theme: ComputedRef<string>;
};
/**
 * @property {string=} scheme? - Scheme souhaité (`'system'` par défaut)
 * @property {string=} dataThemeAttribute? - Nom complet de l’attribut qui contiendra la valeur du thème (`'data-fr-theme'` par défaut)
 */
export declare type UseThemeOptions = {
    scheme?: string;
    dataThemeAttribute?: string;
    localStorageKey?: string;
};
/**
 * Permet de gérer le thème selon le scheme donné.
 * Si dans les options, `scheme` vaut 'system', le thème sera celui du système,
 * si `scheme` vaut `'light'`, le theme sera clair,
 * et s’il vaut `'dark'`, le thème sera sombre.
 *
 * @param {UseThemeOptions=} options - Peut contenir les clés `scheme` pour le scheme voulu, `dataThemeAttribute` pour l’attribut
 *                   qui contiendra la valeur de scheme, et `localStorageKey` pour personnaliser la clé utilisée dans stockage local.
 *
 * @return {UseSchemeResult} Objet contenant la fonction `setScheme` pour changer le scheme, et les
 *          propriétés calculés (réactives et en lecture seule) `theme` et `scheme`.
 */
export declare const useScheme: (options?: UseThemeOptions) => UseSchemeResult | undefined;
